# tsinfer

[![CircleCI](https://circleci.com/gh/tskit-dev/tsinfer.svg?style=svg)](https://circleci.com/gh/tskit-dev/tsinfer) [![Build Status](https://travis-ci.org/tskit-dev/tsinfer.svg?branch=master)](https://travis-ci.org/tskit-dev/tsinfer) [![Documentation Status](https://readthedocs.org/projects/tsinfer/badge/?version=latest)](http://tsinfer.readthedocs.io/en/latest/?badge=latest) [![codecov](https://codecov.io/gh/tskit-dev/tsinfer/branch/master/graph/badge.svg)](https://codecov.io/gh/tskit-dev/tsinfer)


Infer a tree sequence from genetic variation data

Please see the [documentation](http://tsinfer.readthedocs.io/en/latest/) for details.
